@@ -130,12 +130,17 @@ class ArchiveSession(requests.sessions.Session):
 
         logging_config = self.config.get('logging', {})
         if logging_config.get('level'):
-            self.set_file_logger(logging_config.get('level', 'NOTSET'),
-                                 logging_config.get('file', 'internetarchive.log'))
-            if debug or (logger.level <= 10):
+            if logging_config.get('log_to_stdout'):
+                self.set_stream_logger(logging_config.get('level', 'NOTSET'))
+                if debug or (logger.level <= 10):
+                    self.set_stream_logger(logging_config.get('level', 'NOTSET'), "urllib3")
+            else:
                 self.set_file_logger(logging_config.get('level', 'NOTSET'),
-                                     logging_config.get('file', 'internetarchive.log'),
-                                     'urllib3')
+                                     logging_config.get('file', 'internetarchive.log'))
+                if debug or (logger.level <= 10):
+                    self.set_file_logger(logging_config.get('level', 'NOTSET'),
+                                         logging_config.get('file', 'internetarchive.log'),
+                                         'urllib3')
 
     def _get_user_agent_string(self) -> str:
         """Generate a User-Agent string to be sent with every request."""
@@ -235,6 +240,40 @@ class ArchiveSession(requests.sessions.Session):
 
         _log.addHandler(fh)
 
+    def set_stream_logger(
+        self,
+        log_level: str,
+        logger_name: str = 'internetarchive'
+    ) -> None:
+        """Convenience function to quickly configure any level of
+        logging to a stream (stdout).
+
+        :param log_level: A log level as specified in the `logging` module.
+
+        :param logger_name: The name of the logger.
+        """
+        _log_level = {
+            'CRITICAL': 50,
+            'ERROR': 40,
+            'WARNING': 30,
+            'INFO': 20,
+            'DEBUG': 10,
+            'NOTSET': 0,
+        }
+
+        log_format = '%(asctime)s - %(name)s - %(levelname)s - %(message)s'
+
+        _log = logging.getLogger(logger_name)
+        _log.setLevel(logging.DEBUG)
+
+        sh = logging.StreamHandler(stream=sys.stdout)
+        sh.setLevel(_log_level[log_level])
+
+        formatter = logging.Formatter(log_format)
+        sh.setFormatter(formatter)
+
+        _log.addHandler(sh)
+
     def whoami(self) -> str:
         """Return the logged-in user email address.
 
